@@ -23,14 +23,17 @@ from almdrlib.client import Client
 from almdrlib.client import OpenAPIKeyWord
 from almdrlib.region import Region
 from almdrlib.region import Residency
-from almdrlib import __version__ as almdrlib_version
+from almdrlib.version import version as almdrlib_version
 
 from alcli.cliparser import ALCliArgsParser
+from alcli.cliparser import ALCliParserUtils
 from alcli.cliparser import USAGE
 from alcli.clihelp import ALCliMainHelpFormatter
 from alcli.clihelp import ALCliServiceHelpFormatter
 from alcli.clihelp import ALCliOperationHelpFormatter
-from alcli import __version__ as alcli_version
+from alcli.version import version as alcli_version
+
+from alsdkdefs.version import version as alsdkdefs_version
 
 if getattr(sys, 'frozen', False):
     # frozen
@@ -137,7 +140,9 @@ class AlertLogicCLI(object):
     def _create_parser(self, services):
         parser = ALCliArgsParser(
                 services,
-                f"alcli/{alcli_version} Python/{platform.python_version()} almdrlib/{almdrlib_version}",
+                f"alcli/{alcli_version} Python/{platform.python_version()}"
+                f" almdrlib/{almdrlib_version}"
+                f" alsdkdefs/{alsdkdefs_version}",
                 "Alert Logic CLI Utility",
                 prog="alcli")
         
@@ -195,7 +200,7 @@ class ServiceOperation(object):
             try:
                 self._print_result(res.json(), parsed_globals.query)
             except json.decoder.JSONDecodeError:
-                print(f'HTTP Status Code: {res.status_code}')
+                print(f'HTTP Status Code: {res.status_code}\n{res.text}')
 
     def get_service_api(self, service_name):
         return Session.get_service_api(service_name=service_name)
@@ -223,11 +228,15 @@ class ServiceOperation(object):
         return self._operations
 
     def _init_service(self, parsed_globals):
+        account_id = None
+        if hasattr(parsed_globals, 'account_id'):
+            account_id = parsed_globals.account_id
+
         return almdrlib.client(
                 self._name,
                 access_key_id=parsed_globals.access_key_id,
                 secret_key=parsed_globals.secret_key,
-                account_id=parsed_globals.account_id,
+                account_id=account_id,
                 profile=parsed_globals.profile,
                 global_endpoint=parsed_globals.global_endpoint,
                 residency=\
@@ -240,17 +249,39 @@ class ServiceOperation(object):
             p = urlparse(param_value)
             if p.scheme == "file":
                 value_file_path = os.path.abspath(os.path.join(p.netloc, p.path))
-                with open (value_file_path, "r") as value_file:
+                with open(value_file_path, "r") as value_file:
                     param_value = value_file.read()
 
         schema = operation.get_schema()
         parameter = schema[OpenAPIKeyWord.PARAMETERS][param_name]
+        parameter_type = parameter.get(OpenAPIKeyWord.TYPE)
+        oneof = parameter.get(OpenAPIKeyWord.ONE_OF)
+        anyof = parameter.get(OpenAPIKeyWord.ANY_OF)
+        allof = parameter.get(OpenAPIKeyWord.ALL_OF)
 
-        type = parameter[OpenAPIKeyWord.TYPE]
-        if type in OpenAPIKeyWord.SIMPLE_DATA_TYPES:
+        if oneof or anyof or allof:
+            # Attempt to find type in the decomposed schema
+            find_type = [t.get('type') for t in allof or anyof or oneof if t.get('type')]
+            parameter_type = find_type[0] if find_type else None
+
+        if not parameter_type:
+            # If failed to figure parameter_type out, fallback to object
+            parameter_type = OpenAPIKeyWord.OBJECT
+
+        if parameter_type in OpenAPIKeyWord.SIMPLE_DATA_TYPES:
             return param_value
-        
-        if type == OpenAPIKeyWord.OBJECT:
+
+        if parameter_type == OpenAPIKeyWord.ARRAY:
+            items_type = ALCliParserUtils.detect_array_items_type(schema.get('items', {}))
+            if items_type in OpenAPIKeyWord.SIMPLE_DATA_TYPES:
+                return param_value
+            else:
+                try:
+                    return json.loads(param_value)
+                except JSONDecodeError as e:
+                    logging.error(f"{e}")
+
+        if parameter_type in OpenAPIKeyWord.OBJECT:
             try:
                 return json.loads(param_value)
             except JSONDecodeError as e:
@@ -280,7 +311,7 @@ def main():
         print("Running in DEBUG mode")
         logging.basicConfig(level=logging.DEBUG)
     else:
-        logging.basicConfig(level=logging.WARNING)
+        logging.basicConfig(level=logging.ERROR)
 
     cli= AlertLogicCLI()
     cli.main()
